@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013-2018, PyInstaller Development Team.
+# Copyright (c) 2013-2019, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -7,5 +7,6 @@
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
-hiddenimports = ['PySide2.QtCore']
+from PyInstaller.utils.hooks.qt import add_qt5_dependencies
 
+hiddenimports, binaries, datas = add_qt5_dependencies(__file__)
