@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013-2018, PyInstaller Development Team.
+# Copyright (c) 2013-2019, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -10,8 +10,10 @@
 
 import os
 import sys
+import locale
 
-from PyInstaller.compat import is_win, is_darwin, is_unix, is_venv, base_prefix
+from PyInstaller.compat import is_win, is_darwin, is_unix, is_venv, \
+    base_prefix, open_file, text_read_mode
 from PyInstaller.compat import modname_tkinter
 from PyInstaller.depend.bindepend import selectImports, getImports
 from PyInstaller.building.datastruct import Tree
@@ -77,7 +79,9 @@ def _warn_if_activetcl_or_teapot_installed(tcl_root, tcltree):
 
     mentions_activetcl = False
     mentions_teapot = False
-    with open(init_resource, 'r') as init_file:
+    # TCL/TK reads files using the `system encoding <https://www.tcl.tk/doc/howto/i18n.html#system_encoding>`_.
+    with open_file(init_resource, text_read_mode,
+                   encoding=locale.getpreferredencoding()) as init_file:
         for line in init_file.readlines():
             line = line.strip().lower()
             if line.startswith('#'):
