@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013-2016, PyInstaller Development Team.
+# Copyright (c) 2013-2019, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -8,11 +8,8 @@
 #-----------------------------------------------------------------------------
 
 from PyInstaller.utils.hooks import collect_submodules
-hiddenimports = []
 
 # Tested on Windows 7 x64 with Python 2.7.6 x32 using ReportLab 3.0
 # This has been observed to *not* work on ReportLab 2.7
-
-for x in collect_submodules('reportlab.pdfbase'):
-    if x.startswith('reportlab.pdfbase._fontdata_'):
-        hiddenimports.append(x)
+hiddenimports = collect_submodules('reportlab.pdfbase',
+                  lambda name: name.startswith('reportlab.pdfbase._fontdata_'))
