@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013-2018, PyInstaller Development Team.
+# Copyright (c) 2013-2019, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -92,7 +92,7 @@ from xml.dom import Node, minidom
 from xml.dom.minidom import Document, Element
 
 from PyInstaller import compat
-from PyInstaller.compat import architecture, string_types
+from PyInstaller.compat import string_types
 from PyInstaller import log as logging
 from PyInstaller.utils.win32 import winresource
 
@@ -911,7 +911,7 @@ class Manifest(object):
             xmlstr = domtree.toprettyxml(indent, newl, encoding)
         else:
             xmlstr = domtree.toprettyxml(indent, newl)
-        xmlstr = xmlstr.decode().strip(os.linesep).replace(
+        xmlstr = xmlstr.decode(encoding).strip(os.linesep).replace(
                 '<?xml version="1.0" encoding="%s"?>' % encoding,
                 '<?xml version="1.0" encoding="%s" standalone="yes"?>' %
                 encoding)
@@ -1072,8 +1072,7 @@ def create_manifest(filename, manifest, console, uac_admin=False, uac_uiaccess=F
     # only write a new manifest if it is different from the old
     need_new = not os.path.exists(filename)
     if not need_new:
-        with open(filename) as f:
-            old_xml = f.read()
+        old_xml = ManifestFromXMLFile(filename).toprettyxml()
         new_xml = manifest.toprettyxml().replace('\r','')
 
         # this only works if PYTHONHASHSEED is set in environment
@@ -1095,7 +1094,7 @@ def processor_architecture():
     'x86' - 32bit Windows
     'amd64' - 64bit Windows
     """
-    if architecture() == '32bit':
+    if compat.architecture == '32bit':
         return 'x86'
     else:
         return 'amd64'
