@@ -1,13 +1,16 @@
 # fake module to make PyQt5 hooks and run-time-hooks happy
 __pyinstaller_fake_module_marker__ = '__pyinstaller_fake_module_marker__'
 
-class QCoreApplication:
+class QLibraryInfo:
     def __init__(*args, **kw): pass
 
+    PrefixPath = 1
+    BinariesPath = 2
+
     @classmethod
-    def setLibraryPaths(*args, **kw): pass
+    def location(cls, val):
+        return "."
 
-    def libraryPaths(*args, **kw): return ['.']
-
-# required to make hook-PyQt5 happy
-QT_VERSION_STR = '99.99.99'
+    @classmethod
+    def isDebugBuild(cls):
+        return False
