@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2014-2018, PyInstaller Development Team.
+# Copyright (c) 2014-2019, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -77,8 +77,7 @@ def main():
         assert False, "Could not bind server port: all ports in use."
 
     httpd.socket = ssl.wrap_socket(
-        httpd.socket, certfile=SERVER_CERT, server_side=True,
-        ssl_version=ssl.PROTOCOL_TLSv1,
+        httpd.socket, certfile=SERVER_CERT, server_side=True
     )
 
     def ssl_server():
