@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #-----------------------------------------------------------------------------
-# Copyright (c) 2005-2018, PyInstaller Development Team.
+# Copyright (c) 2005-2019, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -351,12 +351,11 @@ def test_stderr_encoding(tmpdir, pyi_builder):
                 # In Python 2 on Mac OS X and Linux 'sys.stderr.encoding' is set to None.
                 # On Windows when running in non-interactive terminal it is None.
                 enc = 'None'
-        elif sys.stderr.isatty() or is_py37:
+        elif sys.stderr.isatty():
             enc = str(sys.stderr.encoding)
         else:
             # For non-interactive stderr use locale encoding - ANSI codepage.
-            # This fixes the test when running with py.test and capturing
-            # output on Python 3.6 and earlier.
+            # This fixes the test when running with py.test and capturing output.
             enc = locale.getpreferredencoding(False)
         f.write(enc)
     pyi_builder.test_script('pyi_stderr_encoding.py')
@@ -371,12 +370,11 @@ def test_stdout_encoding(tmpdir, pyi_builder):
                 # In Python 2 on Mac OS X and Linux 'sys.stdout.encoding' is set to None.
                 # On Windows when running in non-interactive terminal it is None.
                 enc = 'None'
-        elif sys.stdout.isatty() or is_py37:
+        elif sys.stdout.isatty():
             enc = str(sys.stdout.encoding)
         else:
             # For non-interactive stderr use locale encoding - ANSI codepage.
-            # This fixes the test when running with py.test and capturing
-            # output on Python 3.6 and earlier.
+            # This fixes the test when running with py.test and capturing output.
             enc = locale.getpreferredencoding(False)
         f.write(enc)
     pyi_builder.test_script('pyi_stdout_encoding.py')
